==> chemics-20.8.tar.gz: chemics-20.8/chemics/__init__.py <==
# flake8: noqa

from .atomic_elements import atomic_elements

from .bed_expansion_factor import fbexp

from .biomass_composition import biocomp
from .biomass_composition import plot_biocomp

from .bubble_rise_velocity import ubr_kunii
from .bubble_rise_velocity import ubr_holland

from .chemical_equation import ChemicalEquation

from .choking_velocity import uch_bifan
from .choking_velocity import uch_leung

from .conversions import slm_to_lpm
from .conversions import massfrac_to_molefrac
from .conversions import molefrac_to_massfrac

from .devol_time import devol_time

from .dimensionless_numbers import biot
from .dimensionless_numbers import prandtl
from .dimensionless_numbers import pyroI
from .dimensionless_numbers import pyroII
from .dimensionless_numbers import reynolds

from .gas_density import rhog
from .gas_pressure import patm
from .gas_thermal_conductivity import k_gas_inorganic
from .gas_thermal_conductivity import k_gas_organic
from .gas_viscosity import mu_gas
from .gas_viscosity import mu_graham
from .gas_viscosity import mu_herning

from .geldart import geldart_chart

from .minimum_fluidization_velocity import umf_coeff
from .minimum_fluidization_velocity import umf_ergun
from .minimum_fluidization_velocity import umf_reynolds

from .molecular_weight import mw
from .molecular_weight import mw_mix

from .proximate_bases import proximate_bases

from .terminal_velocity import ut
from .terminal_velocity import ut_haider
from .terminal_velocity import ut_ganser

from .transport_disengaging_height import tdh_chan
from .transport_disengaging_height import tdh_horio
from .transport_velocity import utr

from .ultimate_bases import ultimate_bases

from .wood_heat_capacity import cp_wood
from .wood_thermal_conductivity import k_wood

==> chemics-21.7.tar.gz: chemics-21.7/chemics/__init__.py <==
# flake8: noqa

from .atomic_elements import atomic_elements

from .bed_expansion_factor import fbexp

from .biomass_composition import biocomp
from .biomass_composition import plot_biocomp

from .bubble_rise_velocity import ubr_kunii
from .bubble_rise_velocity import ubr_holland

from .chemical_equation import ChemicalEquation

from .choking_velocity import uch_bifan
from .choking_velocity import uch_leung
from .choking_velocity import uch_matsen
from .choking_velocity import uch_psri
from .choking_velocity import uch_punwani
from .choking_velocity import uch_yang
from .choking_velocity import uch_yousfi
from .choking_velocity import uch_zhang

from .conversions import slm_to_lpm
from .conversions import massfrac_to_molefrac
from .conversions import molefrac_to_massfrac

from .devol_time import devol_time

from .dimensionless_numbers import archimedes
from .dimensionless_numbers import biot
from .dimensionless_numbers import peclet
from .dimensionless_numbers import prandtl
from .dimensionless_numbers import pyroI
from .dimensionless_numbers import pyroII
from .dimensionless_numbers import reynolds
from .dimensionless_numbers import schmidt
from .dimensionless_numbers import sherwood
from .dimensionless_numbers import flow_regime

from .gas_density import rhog
from .gas_heat_capacity import cp_gas
from .gas_pressure import patm
from .gas_thermal_conductivity import k_gas_inorganic
from .gas_thermal_conductivity import k_gas_organic
from .gas_viscosity import mu_gas
from .gas_viscosity import mu_graham
from .gas_viscosity import mu_herning

from .geldart import geldart_chart

from .mass_transfer_correlations import molecular_diffusion_coeff
from .mass_transfer_correlations import convective_mt_coeff
from .mass_transfer_correlations import axial_dispersion_coeff
from .mass_transfer_correlations import axial_dispersion_coeff_sc

from .minimum_fluidization_velocity import umf_coeff
from .minimum_fluidization_velocity import umf_ergun
from .minimum_fluidization_velocity import umf_reynolds

from .molecular_weight import mw
from .molecular_weight import mw_mix

from .pressure_drop import pressure_drop_ergun

from .proximate_analysis import Proximate

from .terminal_velocity import ut
from .terminal_velocity import ut_haider
from .terminal_velocity import ut_ganser

from .transport_disengaging_height import tdh_chan
from .transport_disengaging_height import tdh_horio
from .transport_velocity import utr

from .ultimate_analysis import Ultimate

from .wood_heat_capacity import cp_wood
from .wood_thermal_conductivity import k_wood
